@@ -16,7 +16,8 @@ class BrowserEnum(Enum):
 
 
 def launch(domain: str, server_address: Tuple[str, int], browser: BrowserEnum = BrowserEnum.CHROME,
-           restart: bool = False, width: int = 400, height: int = 580, browser_path: str = None, browser_args: List[str] = []):
+           restart: bool = False, width: int = 400, height: int = 580, browser_path: str = None, browser_args: List[str] = [],
+           extensions: str = None):
     browser = browser.value
     pac_script_url = f'http://{server_address[0]}:{server_address[1]}/{domain}.pac'
     app = browsers.get(browser)
@@ -39,21 +40,22 @@ def launch(domain: str, server_address: Tuple[str, int], browser: BrowserEnum =
             'Automatic broswer functinality only avalible on MacOS and Windows for now')
 
     browser_command.append(browser_path)
+
     if restart:
         os.system(restart_command)
     else:
         browser_command.append(user_data_dir)
 
+    if extensions:
+        browser_command.append(f'--load-extension="{extensions}"')
+
     browser_command.extend(browser_args)
     browser_command.extend((
-        # "--disable-web-security",
-        # "--disable-http2",
         "--ignore-certificate-errors",
         "--ignore-urlfetcher-cert-requests",
         "--no-default-browser-check",
 
         f'--host-rules="MAP {domain} {server_address[0]}:{server_address[1]}"',
-        # f'--proxy-pac-url="{pac_script_url}"',
         f"--window-size={width},{height}",
         f'--app="https://{domain}"'
     ))
